eventStream constant
String
const eventStream
The VM service stream route and log events are posted to.
Implementation
static const String eventStream = 'nylo';
The VM service stream route and log events are posted to.
static const String eventStream = 'nylo';