LiveRunAction class

A built-in action run with metro live:run <name>.

Constructors

LiveRunAction(String description, NyCustomCommand create(List<String> arguments))
Creates a LiveRunAction described by description.
const

Properties

create → NyCustomCommand Function(List<String> arguments)
Creates the command with its arguments.
final
description → String
The one-line description shown by metro live:run.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(List<String> arguments) → Future<void>
Runs the action with its arguments, including any shared live flags.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited