metro/live/live_app library

Classes

LiveApp
A running Nylo app that metro live:* can send commands to.
LiveEvent
An event a running app posted to the nylo VM service stream.

Exceptions / Errors

LiveCommandException
Thrown when a live command can't run, with a message for the terminal.
LiveProjectMismatchException
Thrown when a running app was built from a different project.