LiveDaemon class

A Dart Tooling Daemon listed by dart tooling-daemon --list --machine.

Constructors

LiveDaemon({required Uri wsUri, String? workspaceRoot, String? ideName, int? pid})
Creates a LiveDaemon reachable at wsUri.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
ideName → String?
The IDE that started the daemon, when an IDE did.
final
pid → int?
The daemon's process id.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workspaceRoot → String?
The workspace the daemon was started for (a project root for flutter run, the IDE workspace otherwise).
final
wsUri → Uri
The daemon's WebSocket URI, including its secret path.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Object? json) → LiveDaemon?
Parses one entry of dart tooling-daemon --list --machine.