LiveSkippedApp class

An app that matched this project but couldn't be used.

Constructors

LiveSkippedApp(String device, Uri uri, String reason)
Creates a LiveSkippedApp.
const

Properties

device → String
The device name reported by the daemon.
final
hashCode → int
The hash code for this object.
no setterinherited
reason → String
Why the app was skipped.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → Uri
The VM service URI that was tried.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited