usage constant
String
const usage
Usage lines for the shared flags.
Implementation
static const String usage =
'-d, --device Target an app by its number in `metro live:devices` or its device name\n'
' --all Run on every running app of this project\n'
' --json Print machine-readable JSON\n'
' --uri Use this VM service address instead of discovering apps\n'
' --timeout Seconds to wait for each app while discovering (default 3)';