LiveTone enum

How a line of live command output is styled.

Inheritance
Available extensions

Values

plain → const LiveTone

Regular text.

success → const LiveTone

A completed action, shown with a green check.

failure → const LiveTone

A failed action, shown with a red cross.

warning → const LiveTone

Something to pay attention to, shown in yellow.

note → const LiveTone

Secondary information, shown dimmed.

heading → const LiveTone

A title, shown in bold.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<LiveTone>
A constant List of the values in this enum, in order of their declaration.