LiveWiring enum
The result of wiring a registry into the app provider.
Values
- added → const LiveWiring
-
The import and the
nylo.configureargument were added. - alreadyWired → const LiveWiring
-
The app provider already passes it.
- configureNotFound → const LiveWiring
-
No
nylo.configure(...)call was found to add it to. - providerMissing → const LiveWiring
-
There is no app provider file.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
LiveWiring> - A constant List of the values in this enum, in order of their declaration.