LiveTargetSelection<T>.error constructor

const LiveTargetSelection<T>.error(
  1. String? error,
  2. int exitCode, {
  3. List<T> candidates = const [],
})

A failed selection with an error message and exitCode. candidates lists the apps worth showing alongside the message.

Implementation

const LiveTargetSelection.error(
  this.error,
  this.exitCode, {
  this.candidates = const [],
}) : targets = const [];