metro/stubs/deep_link_provider_stub library

Functions

deepLinkProviderStub(ReCase rc) String
This stub is used to create a Deep Link Provider class in the /app/providers/ directory. The provider enables Nylo's deep-link capture and gives a starting point for intercepting incoming URIs.