isFromPackage property
bool
get
isFromPackage
Whether this command was contributed by a dependency package.
Implementation
bool get isFromPackage => package != null;
Whether this command was contributed by a dependency package.
bool get isFromPackage => package != null;