AppBarColors class
Color configuration for the app bar.
Constructors
- AppBarColors({required Color background, required Color content})
-
Creates an AppBarColors configuration.
const
Properties
- background → Color
-
The app bar background color.
final
- content → Color
-
The app bar content/text color.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Color? background, Color? content}) → AppBarColors - Creates a copy with the specified fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited