BottomTabBarColors class

Color configuration for the bottom tab bar.

Constructors

BottomTabBarColors({required Color background, required Color iconSelected, required Color iconUnselected, required Color labelSelected, required Color labelUnselected})
Creates a BottomTabBarColors configuration.
const

Properties

background Color
The bottom tab bar background color.
final
hashCode int
The hash code for this object.
no setterinherited
iconSelected Color
The color for selected tab icons.
final
iconUnselected Color
The color for unselected tab icons.
final
labelSelected Color
The color for selected tab labels.
final
labelUnselected Color
The color for unselected tab labels.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Color? background, Color? iconSelected, Color? iconUnselected, Color? labelSelected, Color? labelUnselected}) BottomTabBarColors
Creates a copy with the specified fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited