ErrorStackStorage class

Default storage implementation using FlutterSecureStorage.

Provides secure, encrypted storage for ErrorStack preferences including theme mode and other settings.

Implemented types

Constructors

ErrorStackStorage({FlutterSecureStorage? storage})
Creates an ErrorStackStorage with optional custom storage instance.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getThemeMode() Future<String?>
Retrieves the stored theme mode.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setThemeMode(String mode) Future<void>
Persists the theme mode.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited