FormValidator.maxLength constructor

FormValidator.maxLength(
  1. int value, {
  2. String? message,
})

Validate that the value is a maximum of value characters message The message to display if the value is invalid value The maximum number of characters

Implementation

FormValidator.maxLength(int value, {String? message}) {
  rules.add(FormRuleMaxLength(value, message));
}