IOSInitializationSettings class

Plugin initialization settings for iOS

Inheritance

Constructors

IOSInitializationSettings({bool requestAlertPermission = true, bool requestSoundPermission = true, bool requestBadgePermission = true, bool requestProvisionalPermission = false, bool requestCriticalPermission = false, bool requestProvidesAppNotificationSettings = false, bool requestCarPlayPermission = false, bool defaultPresentAlert = true, bool defaultPresentSound = true, bool defaultPresentBadge = true, bool defaultPresentBanner = true, bool defaultPresentList = true, List<DarwinNotificationCategory> notificationCategories = const <DarwinNotificationCategory>[]})
Constructs an instance of IOSInitializationSettings.
const

Properties

defaultPresentAlert bool
Configures the default setting on if an alert should be displayed when a notification is triggered while app is in the foreground.
finalinherited
defaultPresentBadge bool
Configures the default setting on if a badge value should be applied when a notification is triggered while app is in the foreground.
finalinherited
defaultPresentBanner bool
Configures the default setting on if the notification should be presented as a banner when a notification is triggered while app is in the foreground.
finalinherited
defaultPresentList bool
Configures the default setting on if the notification should be in the notification centre when notification is triggered while app is in the foreground.
finalinherited
defaultPresentSound bool
Configures the default setting on if a sound should be played when a notification is triggered while app is in the foreground.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
notificationCategories List<DarwinNotificationCategory>
Configure the notification categories (DarwinNotificationCategory) available. This allows for fine-tuning of preview display.
finalinherited
requestAlertPermission bool
Request permission to display an alert.
finalinherited
requestBadgePermission bool
Request permission to badge app icon.
finalinherited
requestCarPlayPermission bool
Request permission to show notifications on CarPlay.
final
requestCriticalPermission bool
Request permission to show critical notifications.
finalinherited
requestProvidesAppNotificationSettings bool
Request permission to provide custom notification settings UI.
finalinherited
requestProvisionalPermission bool
Request permission to send provisional notification for iOS 12+
finalinherited
requestSoundPermission bool
Request permission to play a sound.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited