clearSavedTheme static method
Clear all saved theme preferences.
Useful for testing and development to reset theme preferences.
Implementation
static Future<void> clearSavedTheme() async {
await NyThemeManager.instance.clearSavedTheme();
}
Clear all saved theme preferences.
Useful for testing and development to reset theme preferences.
static Future<void> clearSavedTheme() async {
await NyThemeManager.instance.clearSavedTheme();
}