liveRunActions top-level property
The built-in actions of metro live:run, in the order they're listed.
A built-in action wins over an app command with the same name.
Implementation
final Map<String, LiveRunAction> liveRunActions = {
'data': LiveRunAction(
'Show the data and fields of the page on screen',
_LiveDataCommand.new,
),
'routes': LiveRunAction('List the registered routes', _LiveRoutesCommand.new),
'route': LiveRunAction(
'Open a page, with optional --data',
_LiveRouteCommand.new,
),
'back': LiveRunAction(
'Go back a page, or back to a route',
_LiveBackCommand.new,
),
'deeplink': LiveRunAction(
'Open a deep link, or show how they are set up',
_LiveDeepLinkCommand.new,
),
'storage': LiveRunAction(
'List local storage, or show, save or delete one value',
_LiveStorageCommand.new,
),
'storage:clear': LiveRunAction(
'Clear local storage, with optional --keep',
_LiveStorageClearCommand.new,
),
'backpack': LiveRunAction(
'List Backpack values, or show, save or delete one',
_LiveBackpackCommand.new,
),
'auth': LiveRunAction(
'Show who is signed in, or sign in and out',
_LiveAuthCommand.new,
),
'locale': LiveRunAction('Switch the app\'s language', _LiveLocaleCommand.new),
'theme': LiveRunAction('Switch the app\'s theme', _LiveThemeCommand.new),
'state': LiveRunAction(
'Send data to a state with updateState',
_LiveStateCommand.new,
),
'event': LiveRunAction('Fire one of your events', _LiveEventCommand.new),
'toast': LiveRunAction('Show a toast notification', _LiveToastCommand.new),
};