JsonRpcException class
An error response returned by a JSON-RPC 2.0 peer.
- Implemented types
Constructors
- JsonRpcException(int code, String message, [Object? data])
-
Creates a JsonRpcException from an error
code,messageanddata.
Properties
- code → int
-
The JSON-RPC error code, e.g.
-32601(method not found).final - data → Object?
-
Optional structured error data sent by the peer.
final
- details → String
-
The most useful human-readable text for this error.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
The error message sent by the peer.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited