metro/live/live_discovery
library
Classes
-
LiveAppDescriptor
-
A connected app as described by a daemon's
ConnectedApp service,
parsed from names like Kind: Flutter - Device: iPhone 17e - Package: my_app.
-
LiveDaemon
-
A Dart Tooling Daemon listed by
dart tooling-daemon --list --machine.
-
LiveDiscovery
-
Finds the running apps of one project through the Dart Tooling Daemons
that
flutter run sessions and IDEs register them with.
-
LiveDiscoveryResult
-
The outcome of discovering running apps for a project.
-
LiveSkippedApp
-
An app that matched this project but couldn't be used.