LiveAppDescriptor class
A connected app as described by a daemon's ConnectedApp service,
parsed from names like Kind: Flutter - Device: iPhone 17e - Package: my_app.
Constructors
- LiveAppDescriptor({required String kind, required String device, required String package})
-
Creates a LiveAppDescriptor.
const
Properties
- device → String
-
The device name, e.g.
iPhone 17e.final - hashCode → int
-
The hash code for this object.
no setterinherited
- kind → String
-
The app kind, e.g.
Flutter.final - package → String
-
The app's pubspec package name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parse(
String? name) → LiveAppDescriptor? -
Parses a
ConnectedAppVM servicename, or returns null when it doesn't name a device and package.