LiveDiscoveryResult class
The outcome of discovering running apps for a project.
Constructors
-
LiveDiscoveryResult(List<
LiveApp> apps, List<LiveSkippedApp> skipped) -
Creates a LiveDiscoveryResult.
const
Properties
-
apps
→ List<
LiveApp> -
Connected apps, sorted by device name.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
skipped
→ List<
LiveSkippedApp> -
Apps of this project that didn't respond or don't expose Nylo Live.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited