LiveRunner constructor
LiveRunner({
- LivePrinter? output,
- LiveProject? project,
- LiveDiscoveryFactory? discovery,
- LiveSession? session,
Creates a LiveRunner.
project defaults to the project in the current directory, and
discovery to discovery through the running Dart Tooling Daemons.
Implementation
LiveRunner({
LivePrinter? output,
LiveProject? project,
LiveDiscoveryFactory? discovery,
this.session,
}) : output = output ?? LivePrinter(),
_project = project,
_discovery = discovery;