Interceptor class
Interceptor helps to deal with RequestOptions, Response, and DioException during the lifecycle of a request before it reaches users.
Interceptors are called once per request and response, that means redirects aren't triggering interceptors.
Both extends Interceptor and implements Interceptor are supported.
The request pipeline dispatches exclusively through the public onRequest,
onResponse, and onError methods (via dynamic invocation to capture
runtime Futures from async overrides). Do not add private instance
methods to this class and call them from the pipeline — they would not be
inherited by classes that use implements, causing a NoSuchMethodError.
See also:
- InterceptorsWrapper, the helper class to create Interceptors.
- QueuedInterceptor, resolves interceptors as a task in the queue.
- QueuedInterceptorsWrapper, the helper class to create QueuedInterceptors.
Constructors
- Interceptor()
-
The constructor only helps sub-classes to inherit from.
Do not use it directly.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onError(
DioException err, ErrorInterceptorHandler handler) → void - Called when an exception was occurred during the request.
-
onRequest(
RequestOptions options, RequestInterceptorHandler handler) → void - Called when the request is about to be sent.
-
onResponse(
Response response, ResponseInterceptorHandler handler) → void - Called when the response is about to be resolved.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited