NyCommand class
Model class used for defining commands
Constructors
Properties
- action ↔ Function?
-
Runs the command with the remaining arguments; may return an int exit code.
getter/setter pair
- category ↔ String?
-
The command category, used as the prefix.
getter/setter pair
- description ↔ String?
-
An optional one-line description shown in the Metro menu.
getter/setter pair
- fullName → String
-
The full
category:nameform used to run the command.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- isFromPackage → bool
-
Whether this command was contributed by a dependency package.
no setter
- name ↔ String?
-
The command name, used after the category prefix.
getter/setter pair
- package ↔ String?
-
The package that provides this command, or null for project commands.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited